United States Patent: D645062

| ( 1 of 1 )

United States Patent | D645,062
LaValley , et al. | September 13, 2011

Gripping arm

Claims

CLAIM The ornamental design for a gripping arm, as shown and described.

Inventors: | LaValley; Jason (Bemidji, MN), LaValley; Roger (Bemidji, MN), Kilpo; Lawrence D. (Duluth, MN), Burgess; Michael (Duluth, MN)
Assignee: | LaValley Industries, LLC (Bemidji, MN)
Appl. No.: | D/380,046
Filed: | November 30, 2010

Current U.S. Class: | D15/28
Current International Class: | 1503
Field of Search: | ;D15/21,28 ;175/85 ;294/86.41,81.61,104,106

References Cited [Referenced By]

U.S. Patent Documents

3986619 | October 1976 | Woolslayer et al.
4304433 | December 1981 | Langowski
4595066 | June 1986 | Nelmark et al.
4743056 | May 1988 | Oliason
4744596 | May 1988 | Hiller et al.
D323169 | January 1992 | Saito
5931238 | August 1999 | Gilmore et al.
5975605 | November 1999 | Kot
6220807 | April 2001 | Sorokan
6280119 | August 2001 | Ryan et al.
6543555 | April 2003 | Casagrande
7052060 | May 2006 | Vigholm et al.
7322406 | January 2008 | Wiggins et al.
2006/0137910 | June 2006 | Hamner
2007/0114069 | May 2007 | Hooper et al.
2007/0296229 | December 2007 | Chauvin et al.
2008/0036229 | February 2008 | Oliason
2009/0057019 | March 2009 | LaValley et al.
2010/0164243 | July 2010 | Albin
2010/0307827 | December 2010 | Piipponen
2010/0308609 | December 2010 | LaValley et al.
2011/0081224 | April 2011 | Kessler et al.

Foreign Patent Documents

| 295 02 091 |  | Apr 1995 |  | DE
| 102 06 645 |  | Aug 2003 |  | DE
| 00 65193 |  | Nov 2000 |  | WO

Other References
"Manipulator KM 930," Kinshofer GmbH, available at http://www.kinshofer.com/site.sub.--eng/produkte.sub.--main/main.sub.--km- 930.html; 1 page. cited by other . "Manipulator KM 930," Kinshofer Gmbh, available at http://www.kinshofer.com/site.sub.--eng/produkte.sub.--main/Resources/KM.- sub.--930.sub.--eng.pdf ; 1 page. cited by other . "Selling GB Wood Grapple products," GB Industries Co. Ltd, available at http://kennycho.trustpass.alibaba.com/product/107764499-11334694/Selling.- sub.--GB.sub.--Wood.sub.--Grapple.sub.--products.html ; 3 pages. cited by other . "Selector/Demolition Grabs," McQuaid Engineering Ltd, available at http://www.alibaba.com/product/mcquaid84-215959236-0/Selector.sub.--Demol- ition-Grabs.html ; 3 pages. cited by other . "Kinshofer Manipulators--Kinshofer-KM930," available at http://www.worktruck-outfitters.com/kinshofer-manipulators-p-1281.html ; 4 pages. cited by other . Drawings and Photographs of a Grapple manufactured by Weldco Beales Mfg.; in Applicants possession on or about Mar. 20, 2010; 15 pages. cited by other . Pictures of a grapple mechanism printed from http://rotobec.com/web/2610.sub.--PH.sub.--Pipe.sub.--and.sub.--Pole-Hand- ler.html and http://rotobec.com/resources/images/products/rotations/RGP-252.sub.--main- .jpg on Mar. 30, 2010, but possibly posted on the Internet as early as Sep. 2009; 2 pages. cited by other . Five photographs taken in Jan. 2010 of a grapple mechanism used by Michels Corporation. cited by other . Photograph of Manipulator manufactured by Kinshofer GmbH of Germany (1 page). cited by other . Drawings of Heavy Duty Pole Claw manufactured by EZ-Spot-UR, found online at http://www.ezspotur.com/HDPC-01-0006.sub.--NO.sub.--SETBACK.pdf (1 page). cited by other.

Primary Examiner: Goodwin; Mark
Attorney, Agent or Firm: Hamre, Schumann, Mueller & Larson, P.C.

Description

FIG. 1 is a perspective view of a gripping arm according to the new design;
FIG. 2 is a right side elevation view of the gripping arm depicted in FIG. 1;
FIG. 3 is a front elevation view of the gripping arm depicted in FIG. 1;
FIG. 4 is a rear elevation view of the gripping arm depicted in FIG. 1;
FIG. 5 is a left side elevation view of the gripping arm depicted in FIG. 1;
FIG. 6 is a top plan view of the gripping arm depicted in FIG. 1; and,
FIG. 7 is a bottom plan view of the gripping arm depicted in FIG. 1.
The broken lines in the drawings are for illustrative purposes only and form no part of the claimed design.
* * * * *